Stan Math Library: stan/math/prim/scal/meta/max_size_mvt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
max_size_mvt.hpp File Reference
`#include <stan/math/prim/scal/meta/length_mvt.hpp>`
`#include <cstdlib>`

Go to the source code of this file.

## Namespaces
| stan

## Functions
template<typename T1 , typename T2 >
size_t | stan::max_size_mvt (const T1 &x1, const T2 &x2)
template<typename T1 , typename T2 , typename T3 >
size_t | stan::max_size_mvt (const T1 &x1, const T2 &x2, const T3 &x3)
template<typename T1 , typename T2 , typename T3 , typename T4 >
size_t | stan::max_size_mvt (const T1 &x1, const T2 &x2, const T3 &x3, const T4 &x4)

[ Stan Home Page ] © 2011–2016, Stan Development Team.